@@ -23,7 +23,8 @@ def get_args() -> argparse.Namespace:
     return parser.parse_args()
 
 
-if __name__ == '__main__':
+def main() -> None:
+    """Entry point."""
     args = get_args()
     start_bot = args.start_bot
     quiz_questions_folder_path = args.quiz_questions_folder_path
@@ -35,3 +36,7 @@ if __name__ == '__main__':
 
     if quiz_questions_folder_path:
         send_quiz_content_to_redis(quiz_questions_folder_path)
+
+
+if __name__ == '__main__':
+    main()
